components/buttons/lucky_list_items library

Classes

LuckyListItem
A widget that displays a list item with an icon and a text.
LuckyListItemData
A data class to represent a list item with an icon and a text.
LuckyListItems
A widget that displays a list of items with a divider between them.